MPF Monitor (mpf-monitor)
=========================

<img align="right" width="300" src="mpf-monitor-logo.png"/>

This package is for the Mission Pinball Framework (MPF) Monitor
(mpf-monitor).

The MPF monitor is a graphical app that connects to a live running
instance of MPF and shows the status of various devices. (LEDs,
switches, ball locks, etc.). You can add a picture of your playfield and
drag-and-drop devices to their proper locations so you can interact with
your machine when you're not near your physical machine.

The MPF Monitor can run on Windows, Mac, and Linux. It uses PyQt6
(Python bindings for Qt6) for its visual framework.

Installation & Instructions
---------------------------

Full instructions for installing and using the MPF monitor are included
in the MPF documentation here: https://missionpinball.org/

<img src="mpf-monitor-screenshot.jpg"/>

Support
-------

MPF is open source and has no official support. Some MPF users follow the MPF-users Google group: https://groups.google.com/forum/#!forum/mpf-users. Individual hardware providers may provide additional support for users of their hardware.

Contributing
------------

MPF is a passion project created and maintained by volunteers. If you're a Python coder, documentation writer, or pinball maker, feel free to make a change and submit a pull request. For more information about contributing see the [Contributing Code](https://missionpinball.org/latest/about/contributing_to_mpf/)
and [Contributing Documentation](https://missionpinball.org/latest/about/help_docs/) pages.

License
-------

MPF and related projects are released under the MIT License. Refer to the LICENSE file for details. Docs are released under Creative Commons CC BY 4.0.
